@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -462,7 +462,7 @@ static gboolean session_cb(GIOChannel *chan, GIOCondition cond,
 
 	debug("Got %d bytes of data for AVCTP session %p", ret, session);
 
-	if (ret < sizeof(struct avctp_header)) {
+	if ((unsigned int) ret < sizeof(struct avctp_header)) {
 		error("Too small AVCTP packet");
 		goto failed;
 	}
@@ -477,7 +477,7 @@ static gboolean session_cb(GIOChannel *chan, GIOCondition cond,
 			avctp->cr, avctp->ipid, ntohs(avctp->pid));
 
 	ret -= sizeof(struct avctp_header);
-	if (ret < sizeof(struct avrcp_header)) {
+	if ((unsigned int) ret < sizeof(struct avrcp_header)) {
 		error("Too small AVRCP packet");
 		goto failed;
 	}
@@ -675,6 +675,8 @@ static void avctp_server_cb(GIOChannel *chan, int err, const bdaddr_t *src,
 		goto drop;
 	}
 
+	ba2str(dst, address);
+
 	if (session->sock >= 0) {
 		error("Refusing unexpected connect from %s", address);
 		goto drop;
